pro ssw_expand_times,intimes, otimes, odata, out_style=outstyle, _extra=_extra, debug=debug

;
;+
;   Name: ssw_expand_times
;
;   Purpose: expand time vector to match sample cadence
;
;   Input Parameters:
;      ssw_expand_times, intimes, otimes, odata [,out_style=out_style], $
;                        ddt=ddt, offset_ddt=offset_ddt, $
;                          _extra=_extra
;
;   Output Parameters:
;      otimes - time vector (expanded)
;      odata  - data samples (1D)
;
;    Keyword Parameters:
;      out_style - desired output time style (see anytim.pro) DEF=INTS
;      _extra - Data Tag to extract (determines samples per structure)
;      ddt - delta-T per sample  
;      offset_ddt - optional delta-T (seonds) between intimes and 
;                   first sample   
;      
;-

debug=keyword_set(debug)

if data_chk(_extra,/struct) then tag=(tag_names(_extra))(0) else $
   tag='os1_status1'

val0=gt_tagval(intimes(0),tag,missing=-1)

nsamp=n_elements(val0)           ; number of values per structure
ntimes=n_elements(intimes)       ; 

utime=anytim(intimes) 

timearr=dblarr(nsamp,ntimes)

case 1 of    
   n_elements(ddt) eq 1: ddtr=replicate(ddt(0),ntimes)
   n_elements(ddt) eq ntimes: ddtr=ddt
   else: begin 
      dpr=gt_dp_rate(intimes)
      ddt=fltarr(n_elements(intimes))
      ddtr=(ddt+(dpr eq 1)*64 + (dpr eq 2)*16.  + (dpr eq 4)*2.)/float(nsamp)
   endcase
endcase

for i=0,nsamp-1 do timearr(i,*)=utime+(i*ddtr)

n1d=nsamp*ntimes

if n_elements(out_style) eq 0 then out_style='ints'
otimes=anytim(reform(timearr,n1d) ,out_style=out_style)

odata=gt_tagval(intimes,tag,missing=0)
if n_elements(odata) ne n1d then box_message,'Mismatch in times:data' else $
   odata=reform(odata,n1d)
if debug then stop
return
end

